%% ==========================================================
%% Calc_Powers.m
%% Calc powers as fn of windspeed for several turbines
%% CBP 11-11-21
%% ==========================================================

clf;
clear all;  
hold off;

% Common
rho = 1.2;

choice = input('Choose turbine: 1 CART3. 2 NREL 5MW');

%% Data for various turbines

% Seiments SWT-3.6-107
R = 52;
hubH = 83/5; % hub height (m)
vCutIn = 4.0;
vRated = 13.5; %rated wind speed in m/s
vCutOut = 25;
% cut in rotor speed (rpm) 6.9
% rated rotor speed 12.1 (rpm)
% rated tip speed 80 m/s
% tsrOptimal = 7.55;
% cPmax = 0.482; % peak power coefficient
pRated = 3.6*10e5;

% NREL 1.5 MW Turbine -------------------------------
R = 77.0/2.0;
hubH = 80; % hub height (m)
vRated = 14; %rated wind speed in m/s
vCutOut = 25;
% rotor speed range 10-20 (rpm)
  
if(choice == 1)
% CART3 Parameters ---------------------------------
% Power rating 600 kW
% Some data from ?? Paper
% Pitch 0 deg
R = 20.0 %Tip radius
BlPitch = 2.7 %Initial pitch in degrees
% rated rotor speed 37.1 rpm
vCutIn = 5.0
vRated = 11.7 %rated wind speed in m/s
vCutOut = 25
cPmax = 0.4633
tsrOptimal = 6.6
pRated = 600000

elseif(choice == 2)
% NREL 5 MW Turnine ---------------------------------
R = 126.0/2.0
hubH = 90; % hub height (m)
vCutIn = 3.0
vRated = 11.4 %rated wind speed in m/s
vCutOut = 25
% cut in rotor speed (rpm) 6.9
% rated rotor speed 12.1 (rpm)
% rated tip speed 80 m/s
tsrOptimal = 7.55
cPmax = 0.482 % peak power coefficient
pRated = 5.2966*10e5
endif




% Calculations for the chosen turbine ---------------
% Calc the wind power available over whole range
v1 = [0:0.01:vCutOut*1.25];
p1 = 0.5*rho*pi*R^2*v1.^3;
% Now the Betz limit
p1b = 0.59*p1;
plot(v1,p1,'b --',v1,p1b,'g --');
axis([0,vCutOut*1.25,0,pRated*1.25]);
grid;
hold on;

% Calc power for actual turbine, region 2
v2 = [vCutIn:0.01:vRated];
p2 = 0.5*rho*pi*R^2*v2.^3*cPmax;
plot(v2,p2,'r');

p2Max = max(p2);
% Now draw lines for region 3
line([vRated,vCutOut],[pRated,pRated],"color","r");
line([vCutOut,vCutOut],[0,pRated],"color","r");

% Now draw lines for region 1
line([0,vCutIn],[0,0],"color","r");
line([vCutIn,vCutIn],[0,p2(1)],"color","r");

xlabel('Wind s[eed (m/s)');
ylabel('Power (watts)');
if(choice == 1)
  title('Power versus windspeed (NREL CART3 turbine)');
elseif (choice == 2)
  title('Power versus windspeed (NREL 5MW reference turbine)');
endif
legend({'wind power','Betz limit','Turbine power'},'Location','northwest')
