%% ==========================================================
%% Plot_Power_WindV.m
%% Calc powers as fn of windspeed for CART3 Turbine
%% Lets user add own data
%% CBP 18-11-21
%% ==========================================================

clf;
clear all;  
hold off;

% User data goes here
A = [
10  339400
11  451675


];


% Common
rho = 1.2;
% CART3 Parameters ---------------------------------
% Power rating 600 kW
% Some data from ?? Paper
% Pitch 0 deg
R = 20.0 %Tip radius
BlPitch = 2.7 %Initial pitch in degrees
% rated rotor speed 37.1 rpm
vCutIn = 5.0
vRated = 11.7 %rated wind speed in m/s
vCutOut = 25
cPmax = 0.4633
tsrOptimal = 6.6
pRated = 600000


% Calculations for the chosen turbine ---------------
% Calc the wind power available over whole range
v1 = [0:0.01:vCutOut*1.25];
p1 = 0.5*rho*pi*R^2*v1.^3;
% Now the Betz limit
p1b = 0.59*p1;
plot(v1,p1,'b --',v1,p1b,'g --');
axis([0,vCutOut*1.25,0,pRated*1.25]);
grid;
hold on;

% Calc power for actual turbine, region 2
v2 = [vCutIn:0.01:vRated];
p2 = 0.5*rho*pi*R^2*v2.^3*cPmax;
plot(v2,p2,'r');

p2Max = max(p2);
% Now draw lines for region 3
line([vRated,vCutOut],[pRated,pRated],"color","r");
line([vCutOut,vCutOut],[0,pRated],"color","r");

% Now draw lines for region 1
line([0,vCutIn],[0,0],"color","r");
line([vCutIn,vCutIn],[0,p2(1)],"color","r");

% Now plot user data
plot(A(:,1),A(:,2),'ro');

xlabel('Wind s[eed (m/s)');
ylabel('Power (watts)');
title('Power versus windspeed (NREL CART3 turbine)');

legend({'wind power','Betz limit','Turbine power'},'Location','northwest')
