% =============================================================================
% Power_Radius_Fit
% Auto Fit of y = Ax^2 + Bx + C
% x is windspeed y is power
% =============================================================================

pkg load statistics
% Fill-in your data here. The first 
% column is distance, the second is width

A = [
10 84800
20 339350
25 530235
30 763589
35 1242353
%40 2192847
];

radius = A(:,1);   % distance
power = A(:,2);   % width

% plot raw data
plot(radius,power,'o');

% Here is the model dist = m*(1/w) + c
modelfun = @(p,x) (p(1)*x.^(2.0))

% YOU MUST ADJUST THE FOLLOWING LINE WITH YOUR ESTIMATED PARAMETER VALUES
startingVals = [848];
[coefEsts,R,J] = nlinfit(radius,power,modelfun,startingVals);
disp(' ');
disp('Estimated Coefficienst'); disp(coefEsts);

% Get smallest and largest x-values 
minX = min(A(:,1));
maxX = max(A(:,1));
xgrid = linspace(minX,maxX,100); 

line(xgrid,modelfun(coefEsts,xgrid), 'Color','r');
set(gca,"fontsize",14);
ylabel('power')
xlabel('radiuw');

disp(' ' );
disp('95% confidence intervals for parameters');
bci = nlparci(coefEsts,R,J);
disp(bci);

f = modelfun(coefEsts,radius);

disp(' ' );
disp('rms error = ');
err = power - f;
err2 = err.^2;
mse = mean(err2);
rmse = sqrt(mse);
disp(rmse);

ssResid = sum(R.^2);
ssTotal = sum((power-mean(power)).^2);
r2 = 1 - (ssResid/ssTotal);
disp('  ');
disp('r2 value = '); disp(r2);